# API Reference

Complete API reference for all **132 builders** across
**9 modules**.

## Modules

| Module | Builders | Link |
|--------|----------|------|
| `agent` | 2 | [agent](agent.md) |
| `config` | 38 | [config](config.md) |
| `executor` | 5 | [executor](executor.md) |
| `planner` | 3 | [planner](planner.md) |
| `plugin` | 12 | [plugin](plugin.md) |
| `runtime` | 3 | [runtime](runtime.md) |
| `service` | 15 | [service](service.md) |
| `tool` | 51 | [tool](tool.md) |
| `workflow` | 3 | [workflow](workflow.md) |
| `prompt` | P | [prompt](prompt.md) |
| `context` | C | [context](context.md) |
| `transforms` | S | [transforms](transforms.md) |
| `artifacts` | A | [artifacts](artifacts.md) |
| `middleware` | M | [middleware](middleware.md) |
| `tools` | T | [tools](tools.md) |
| `contracts` | — | [contracts](contracts.md) |
| `eval` | — | [eval](eval.md) |
| `visibility` | — | [visibility](visibility.md) |

```{toctree}
:hidden:

agent
config
executor
planner
plugin
runtime
service
tool
workflow
prompt
context
transforms
artifacts
middleware
tools
contracts
eval
visibility
```
